@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2013-2020 Canonical, Ltd.
+ * Copyright (C) 2013-2021 Canonical, Ltd.
+ * Copyright (C) 2021 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * Author: Colin Ian King <colin.king@canonical.com>
+ * Author: Colin Ian King <colin.i.king@gmail.com>
  */
 
 #define _GNU_SOURCE
@@ -923,6 +924,8 @@ static void syscall_get_arg_data(
 	size_t i, n = (len + sizeof(unsigned long) - 1) / sizeof(unsigned long);
 	unsigned long tmpdata[n];
 
+	(void)memset(tmpdata, 0, sizeof(tmpdata));
+
 	for (i = 0; i < n; i++)
 		tmpdata[i] = ptrace(PTRACE_PEEKDATA, pid,
 				addr + (sizeof(unsigned long) * i), NULL);
