@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2013-2020 Canonical, Ltd.
+ * Copyright (C) 2013-2021 Canonical, Ltd.
+ * Copyright (C) 2021 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * Author: Colin Ian King <colin.king@canonical.com>
+ * Author: Colin Ian King <colin.i.king@gmail.com>
  */
 #define _GNU_SOURCE
 
@@ -47,7 +48,7 @@ struct timeval timeval_add(const struct timeval *a, const struct timeval *b)
 	if (ret.tv_usec > 1000000) {
 		int nsec = (ret.tv_usec / 1000000);
 		ret.tv_sec += nsec;
-		ret.tv_usec -= (1000000 * nsec);
+		ret.tv_usec -= (1000000ULL * nsec);
 	}
 
 	return ret;
@@ -69,12 +70,12 @@ struct timeval timeval_sub(
 	if (a->tv_usec < _b.tv_usec) {
 		int nsec = ((_b.tv_usec - a->tv_usec) / 1000000) + 1;
 		_b.tv_sec += nsec;
-		_b.tv_usec -= (1000000 * nsec);
+		_b.tv_usec -= (1000000ULL * nsec);
 	}
 	if (a->tv_usec - _b.tv_usec > 1000000) {
 		int nsec = (a->tv_usec - _b.tv_usec) / 1000000;
 		_b.tv_sec -= nsec;
-		_b.tv_usec += (1000000 * nsec);
+		_b.tv_usec += (1000000ULL * nsec);
 	}
 
 	ret.tv_sec = a->tv_sec - _b.tv_sec;
